### Name: interaction.rsf
### Title: VIMP for Single or Grouped Variables
### Aliases: interaction.rsf
### Keywords: file

### ** Examples

#------------------------------------------------------------------------
# Example of paired-VIMP. 
# Veteran data.

data(veteran, package = "randomSurvivalForest") 
v.out <- rsf(Survrsf(time,status)~., veteran, ntree = 1000, forest = TRUE)
interaction.rsf(v.out, c("karno","celltype"))$importance

## Not run: 
##D #------------------------------------------------------------------------
##D # Individual VIMP for data restricted to events only.
##D # PBC data.
##D 
##D data(pbc, package = "randomSurvivalForest") 
##D rsf.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000, forest = TRUE)
##D o.r <- rev(order(rsf.out$importance))
##D VIMP <- rsf.out$importance[o.r]
##D VIMP.events <- rep(0, length(VIMP))
##D names(VIMP.events) <- names(VIMP) 
##D events <- which(rsf.out$cens == 1)
##D VIMP.events <-
##D  interaction.rsf(rsf.out, names(VIMP), events, joint = FALSE)$importance
##D VIMP.all <- as.data.frame(cbind(VIMP.events = VIMP.events, VIMP = VIMP))
##D print(round(VIMP.all, 3))
##D 
##D #------------------------------------------------------------------------
##D # Estimate variability of VIMP in two ways (PBC data):
##D # (i)  Monte Carlo:  Estimates variability of the procedure
##D # (ii) Bootstrap:    Estimates statistical variability
##D 
##D data(pbc, package = "randomSurvivalForest") 
##D rsf.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000, forest = TRUE)
##D o.r <- rev(order(rsf.out$importance))
##D VIMP <- rsf.out$importance[o.r]
##D subset.index <- 1:nrow(rsf.out$predictors)
##D VIMP.mc <- VIMP.boot <- NULL
##D for (k in 1:100) {
##D   cat("iteration:", k , "\n")
##D   VIMP.mc <-
##D     cbind(VIMP.mc, interaction.rsf(rsf.out, names(VIMP), joint = FALSE)$importance)
##D   VIMP.boot <-
##D     cbind(VIMP.boot, interaction.rsf(rsf.out, names(VIMP),
##D       subset = sample(subset.index, replace = TRUE), joint = FALSE)$importance)
##D }
##D VIMP.mc <- as.data.frame(cbind(VIMP.mean = apply(VIMP.mc, 1, mean),
##D                     VIMP.sd = apply(VIMP.mc, 1, sd)))
##D VIMP.boot <- as.data.frame(cbind(VIMP.mean = apply(VIMP.boot, 1, mean),
##D                     VIMP.sd = apply(VIMP.boot, 1, sd)))
##D rownames(VIMP.mc) <- rownames(VIMP.boot) <- names(VIMP)
##D print(round(VIMP.mc, 3))
##D print(round(VIMP.boot, 3))
## End(Not run)



