### Name: rsf2pmml
### Title: Save Random Survival Forest As PMML
### Aliases: rsf2pmml
### Keywords: survival tree

### ** Examples

  # Example 1:  Growing a forest, saving it as a PMML document,
  # restoring the forest from the PMML document, and using this forest to
  # perform prediction.

  ## Not run: 
##D   library("XML")
##D 
##D   data(veteran, package = "randomSurvivalForest")
##D   veteran.out <- rsf(Survrsf(time, status)~.,
##D         data = veteran,
##D         ntree = 5,
##D         forest = TRUE)
##D   veteran.forest <- veteran.out$forest
##D   veteran.pmml <- rsf2pmml(veteran.forest)
##D 
##D   # Save the document to disk.
##D   saveXML(veteran.pmml, "veteran.forest.xml")
##D   veteran.pmml <- xmlRoot(xmlTreeParse("veteran.forest.xml"))
##D 
##D   partial.forest <- pmml2rsf(veteran.pmml)
##D 
##D   # The PMML forest object must be massaged before it can be used
##D   # for prediction as follows:
##D   veteran.restored.forest <- list(
##D                       nativeArray=partial.forest$nativeArray, 
##D                       nativeFactorArray=partial.forest$nativeFactorArray,
##D                       timeInterest=partial.forest$timeInterest, 
##D                       predictorNames=partial.forest$predictorNames,
##D                       seed=partial.forest$seed
##D                       formula=partialForest$formula,
##D                       predictors=veteran.forest$predictors,
##D                       time=veteran.forest$time,
##D                       cens=veteran.forest$cens)
##D 
##D   # The actual time, censoring and prediction values of the data set
##D   # used to grow the forest are not contained in the PMML
##D   # representation of the forest.  If the user has access to the original
##D   # datafile that was used to grow the forest, this information can be
##D   # easily recovered.  The names corresponding to the time, censoring and
##D   # prediction data are all retained in the PMML representation of the forest.
##D 
##D   class(veteran.restored.forest) <- c("rsf", "forest")
##D   veteran.restored.out <- predict.rsf(veteran.restored.forest, test=veteran)
##D 
## End(Not run)



